@@ -10,6 +10,7 @@
     use test_support
     use pyplot_module
     use iso_fortran_env
+    use root_module, only: root_method_brent
 
     implicit none
 
@@ -29,7 +30,7 @@
     integer :: ilinestyle
 
     integer,parameter :: font_size = 40
-    integer,parameter :: legend_fontsize = 40
+    integer,parameter :: legend_fontsize = 30
     integer,parameter :: max_number_of_methods = 40 !! defines the step size for the colors
 
     character(len=2),dimension(*),parameter :: linestyle = ['- ', '--', ': ']
@@ -69,6 +70,10 @@
     allocate(rkdp54_class   :: s); call run_all_tests()
     allocate(rkt54_class    :: s); call run_all_tests()
     allocate(rks54_class    :: s); call run_all_tests()
+    allocate(rkpp54_class   :: s); call run_all_tests()
+    allocate(rkpp54b_class  :: s); call run_all_tests()
+    allocate(rkbs54_class   :: s); call run_all_tests()
+    allocate(rkss54_class   :: s); call run_all_tests()
     end if
     allocate(rkdp65_class   :: s); call run_all_tests()
     allocate(rkc65_class    :: s); call run_all_tests()
@@ -76,23 +81,29 @@
     allocate(rkv65e_class   :: s); call run_all_tests()
     allocate(rkv65r_class   :: s); call run_all_tests()
     allocate(rkv65_class    :: s); call run_all_tests()
+    allocate(dverk65_class  :: s); call run_all_tests()
     allocate(rktf65_class   :: s); call run_all_tests()
     allocate(rktp75_class   :: s); call run_all_tests()
     allocate(rktmy7_class   :: s); call run_all_tests()
+    allocate(rktmy7s_class   :: s); call run_all_tests()
     allocate(rkv76e_class   :: s); call run_all_tests()
     allocate(rkv76r_class   :: s); call run_all_tests()
+    allocate(rkss76_class   :: s); call run_all_tests()
     allocate(rkf78_class    :: s); call run_all_tests()
     allocate(rkv78_class    :: s); call run_all_tests()
+    allocate(rkdp85_class   :: s); call run_all_tests()
     allocate(rktp86_class   :: s); call run_all_tests()
     allocate(rkdp87_class   :: s); call run_all_tests()
     allocate(rkv87e_class   :: s); call run_all_tests()
     allocate(rkv87r_class   :: s); call run_all_tests()
+    allocate(rkev87_class   :: s); call run_all_tests()
     allocate(rkk87_class    :: s); call run_all_tests()
     allocate(rkf89_class    :: s); call run_all_tests()
     allocate(rkv89_class    :: s); call run_all_tests()
     allocate(rkt98a_class   :: s); call run_all_tests()
     allocate(rkv98e_class   :: s); call run_all_tests()
     allocate(rkv98r_class   :: s); call run_all_tests()
+    allocate(rks98_class    :: s); call run_all_tests()
     allocate(rkf108_class   :: s); call run_all_tests()
     allocate(rkc108_class   :: s); call run_all_tests()
     allocate(rkb109_class   :: s); call run_all_tests()
@@ -103,8 +114,8 @@
 
     ! save plot:
     write(rstr,'(I3)') wp
-    call plt%savefig(figfile='rk_test_variable_step_R'//trim(adjustl(rstr))//'.png',istat=istat)
-    call plt2%savefig(figfile='rk_test_variable_step_FIXED_MODE_R'//trim(adjustl(rstr))//'.png',istat=istat)
+    call plt%savefig(figfile='rk_test_variable_step_R'//trim(adjustl(rstr))//'.pdf',istat=istat)
+    call plt2%savefig(figfile='rk_test_variable_step_FIXED_MODE_R'//trim(adjustl(rstr))//'.pdf',istat=istat)
 
     contains
 !*****************************************************************************************
@@ -425,7 +436,8 @@
 
         call s2%initialize(n=n,f=twobody,g=twobody_event,&
                            rtol=[1.0e-12_wp],atol=[1.0e-12_wp],&
-                           stepsize_method=sz)
+                           stepsize_method=sz,&
+                           solver = root_method_brent) ! specify root solver
 
         fevals = 0
         first = .true.
